@@ -1,4 +1,3 @@
-const char loaders_rcs[] = "$Id: loaders.c,v 1.105 2016/05/25 10:50:55 fabiankeil Exp $";
 /*********************************************************************
  *
  * File        :  $Source: /cvsroot/ijbswa/current/loaders.c,v $
@@ -63,8 +62,6 @@ const char loaders_rcs[] = "$Id: loaders.c,v 1.105 2016/05/25 10:50:55 fabiankei
 #include "urlmatch.h"
 #include "encode.h"
 
-const char loaders_h_rcs[] = LOADERS_H_VERSION;
-
 /*
  * Currently active files.
  * These are also entered in the main linked list of files.
@@ -74,13 +71,51 @@ const char loaders_h_rcs[] = LOADERS_H_VERSION;
 static struct file_list *current_trustfile      = NULL;
 #endif /* def FEATURE_TRUST */
 
+#ifndef FUZZ
 static int load_one_re_filterfile(struct client_state *csp, int fileid);
+#endif
 
 static struct file_list *current_re_filterfile[MAX_AF_FILES]  = {
    NULL, NULL, NULL, NULL, NULL,
    NULL, NULL, NULL, NULL, NULL
 };
 
+/*********************************************************************
+ *
+ * Function    :  free_csp_resources
+ *
+ * Description :  Frees memory referenced by the csp that isn't
+ *                shared with other csps.
+ *
+ * Parameters  :
+ *          1  :  csp = Current client state (buffers, headers, etc...)
+ *
+ * Returns     :  N/A
+ *
+ *********************************************************************/
+void free_csp_resources(struct client_state *csp)
+{
+   freez(csp->ip_addr_str);
+#ifdef FEATURE_CLIENT_TAGS
+   freez(csp->client_address);
+#endif
+   freez(csp->listen_addr_str);
+   freez(csp->client_iob->buf);
+   freez(csp->iob->buf);
+   freez(csp->error_message);
+
+   if (csp->action->flags & ACTION_FORWARD_OVERRIDE &&
+      NULL != csp->fwd)
+   {
+      unload_forward_spec(csp->fwd);
+   }
+   free_http_request(csp->http);
+
+   destroy_list(csp->headers);
+   destroy_list(csp->tags);
+
+   free_current_action(csp->action);
+}
 
 /*********************************************************************
  *
@@ -181,27 +216,6 @@ unsigned int sweep(void)
       {
          last_active->next = client_list->next;
 
-         freez(csp->ip_addr_str);
-#ifdef FEATURE_CLIENT_TAGS
-         freez(csp->client_address);
-#endif
-         freez(csp->listen_addr_str);
-         freez(csp->client_iob->buf);
-         freez(csp->iob->buf);
-         freez(csp->error_message);
-
-         if (csp->action->flags & ACTION_FORWARD_OVERRIDE &&
-             NULL != csp->fwd)
-         {
-            unload_forward_spec(csp->fwd);
-         }
-         free_http_request(csp->http);
-
-         destroy_list(csp->headers);
-         destroy_list(csp->tags);
-
-         free_current_action(csp->action);
-
 #ifdef FEATURE_STATISTICS
          urls_read++;
          if (csp->flags & CSP_FLAG_REJECTED)
@@ -296,12 +310,6 @@ int check_file_changed(const struct file_list * current,
    fs->filename = strdup_or_die(filename);
    fs->lastmodified = statbuf->st_mtime;
 
-   if (fs->filename == NULL)
-   {
-      /* Out of memory error */
-      freez (fs);
-      return 1;
-   }
    *newfl = fs;
    return 1;
 }
@@ -361,6 +369,7 @@ jb_err simple_read_line(FILE *fp, char **dest, int *newline)
    for (;;)
    {
       ch = getc(fp);
+
       if (ch == EOF)
       {
          if (len > 0)
@@ -417,6 +426,7 @@ jb_err simple_read_line(FILE *fp, char **dest, int *newline)
       }
       else if (ch == 0)
       {
+         /* XXX: Why do we allow this anyway? */
          *p = '\0';
          *dest = buf;
          return JB_ERR_OK;
@@ -1087,7 +1097,6 @@ int load_one_re_filterfile(struct client_state *csp, int fileid)
    struct file_list *fs;
 
    char *buf = NULL;
-   int error;
    unsigned long linenum = 0;
    pcrs_job *dummy, *lastjob = NULL;
 
@@ -1217,6 +1226,7 @@ int load_one_re_filterfile(struct client_state *csp, int fileid)
 #ifdef FEATURE_EXTERNAL_FILTERS
       if ((bl != NULL) && (bl->type == FT_EXTERNAL_CONTENT_FILTER))
       {
+         jb_err jb_error;
          /* Save the code as "pattern", but do not compile anything. */
          if (bl->patterns->first != NULL)
          {
@@ -1224,8 +1234,8 @@ int load_one_re_filterfile(struct client_state *csp, int fileid)
                "Did you forget to escape a line break?",
                bl->name);
          }
-         error = enlist(bl->patterns, buf);
-         if (JB_ERR_MEMORY == error)
+         jb_error = enlist(bl->patterns, buf);
+         if (JB_ERR_MEMORY == jb_error)
          {
             log_error(LOG_LEVEL_FATAL,
                "Out of memory while enlisting external filter code \'%s\' for filter %s.",
@@ -1237,17 +1247,19 @@ int load_one_re_filterfile(struct client_state *csp, int fileid)
 #endif
       if (bl != NULL)
       {
+         int pcrs_error;
+         jb_err jb_error;
          /*
           * Save the expression, make it a pcrs_job
           * and chain it into the current filter's joblist
           */
-         error = enlist(bl->patterns, buf);
-         if (JB_ERR_MEMORY == error)
+         jb_error = enlist(bl->patterns, buf);
+         if (JB_ERR_MEMORY == jb_error)
          {
             log_error(LOG_LEVEL_FATAL,
                "Out of memory while enlisting re_filter job \'%s\' for filter %s.", buf, bl->name);
          }
-         assert(JB_ERR_OK == error);
+         assert(JB_ERR_OK == jb_error);
 
          if (pcrs_job_is_dynamic(buf))
          {
@@ -1279,11 +1291,11 @@ int load_one_re_filterfile(struct client_state *csp, int fileid)
             continue;
          }
 
-         if ((dummy = pcrs_compile_command(buf, &error)) == NULL)
+         if ((dummy = pcrs_compile_command(buf, &pcrs_error)) == NULL)
          {
             log_error(LOG_LEVEL_ERROR,
                "Adding re_filter job \'%s\' to filter %s failed: %s",
-               buf, bl->name, pcrs_strerror(error));
+               buf, bl->name, pcrs_strerror(pcrs_error));
             freez(buf);
             continue;
          }
