@@ -1,13 +1,12 @@
 #ifndef SSPLIT_H_INCLUDED
 #define SSPLIT_H_INCLUDED
-#define SSPLIT_H_VERSION "$Id: ssplit.h,v 1.11 2012/06/08 15:15:11 fabiankeil Exp $"
 /*********************************************************************
  *
  * File        :  $Source: /cvsroot/ijbswa/current/ssplit.h,v $
  *
  * Purpose     :  A function to split a string at specified deliminters.
  *
- * Copyright   :  Written by and Copyright (C) 2001 the SourceForge
+ * Copyright   :  Written by and Copyright (C) 2001 members of the
  *                Privoxy team. http://www.privoxy.org/
  *
  *                Based on the Internet Junkbuster originally written
@@ -35,20 +34,8 @@
  *********************************************************************/
 
 
-#ifdef __cplusplus
-extern "C" {
-#endif
-
 extern int ssplit(char *str, const char *delim, char *vec[], size_t vec_len);
 
-/* Revision control strings from this header and associated .c file */
-extern const char ssplit_rcs[];
-extern const char ssplit_h_rcs[];
-
-#ifdef __cplusplus
-} /* extern "C" */
-#endif
-
 #endif /* ndef SSPLIT_H_INCLUDED */
 
 /*
