@@ -1,6 +1,5 @@
 #ifndef W32LOG_H_INCLUDED
 #define W32LOG_H_INCLUDED
-#define W32LOG_H_VERSION "$Id: w32log.h,v 1.17 2013/11/24 14:23:28 fabiankeil Exp $"
 /*********************************************************************
  *
  * File        :  $Source: /cvsroot/ijbswa/current/w32log.h,v $
@@ -84,10 +83,6 @@ extern void TermLogWindow(void);
 extern void ShowLogWindow(BOOL bShow);
 extern void LogShowActivity(void);
 
-/* Revision control strings from this header and associated .c file */
-extern const char w32log_rcs[];
-extern const char w32log_h_rcs[];
-
 #endif /* ndef W32LOG_H_INCLUDED */
 
 
