@@ -1,6 +1,5 @@
 #ifndef W32TASKBAR_H_INCLUDED
 #define W32TASKBAR_H_INCLUDED
-#define W32TASKBAR_H_VERSION "$Id: w32taskbar.h,v 1.9 2013/11/24 14:23:28 fabiankeil Exp $"
 /*********************************************************************
  *
  * File        :  $Source: /cvsroot/ijbswa/current/w32taskbar.h,v $
@@ -40,10 +39,6 @@ extern BOOL TrayAddIcon(HWND hwnd, UINT uID, HICON hicon, const char *pszToolTip
 extern BOOL TraySetIcon(HWND hwnd, UINT uID, HICON hicon);
 extern BOOL TrayDeleteIcon(HWND hwnd, UINT uID);
 
-/* Revision control strings from this header and associated .c file */
-extern const char w32taskbar_rcs[];
-extern const char w32taskbar_h_rcs[];
-
 #endif /* ndef W32TASKBAR_H_INCLUDED */
 
 
